<?php
/**
 * The WP Business functions and definitions
 *
 * @package The WP Business
 */
/**
 * Set the content width based on the theme's design and stylesheet.
 */

if ( ! function_exists( 'the_wp_business_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
 
/* Breadcrumb Begin */
function the_wp_business_the_breadcrumb() {
	if (!is_home()) {
		echo '<a href="';
			echo esc_url( home_url() );
		echo '">';
			bloginfo('name');
		echo "</a> ";
		if (is_category() || is_single()) {
			the_category(',');
			if (is_single()) {
				echo "<span> ";
					the_title();
				echo "</span> ";
			}
		} elseif (is_page()) {
			the_title();
		}
	}
}

/* Theme Setup */
function the_wp_business_setup() {

	if ( ! isset( $content_width ) )
		$content_width = 640; /* pixels */
	load_theme_textdomain( 'the-wp-business', get_template_directory() . '/languages' );
	
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-logo', array(
		'height'      => 240,
		'width'       => 240,
		'flex-height' => true,
	) );
	add_image_size('the-wp-business-homepage-thumb',240,145,true);
	
    register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'the-wp-business' ),
	) );

	add_theme_support( 'custom-background', array(
		'default-color' => 'f1f1f1'
	) );
		/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style( array( 'css/editor-style.css', the_wp_business_font_url() ) );
}
endif;
add_action( 'after_setup_theme', 'the_wp_business_setup' );

/* Theme Widgets Setup */
function the_wp_business_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'the-wp-business' ),
		'description'   => __( 'Appears on blog page sidebar', 'the-wp-business' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'the-wp-business' ),
		'description'   => __( 'Appears on page sidebar', 'the-wp-business' ),
		'id'            => 'sidebar-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 1', 'the-wp-business' ),
		'description'   => __( 'Appears on footer', 'the-wp-business' ),
		'id'            => 'footer-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 2', 'the-wp-business' ),
		'description'   => __( 'Appears on footer', 'the-wp-business' ),
		'id'            => 'footer-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 3', 'the-wp-business' ),
		'description'   => __( 'Appears on footer', 'the-wp-business' ),
		'id'            => 'footer-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 4', 'the-wp-business' ),
		'description'   => __( 'Appears on footer', 'the-wp-business' ),
		'id'            => 'footer-4',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'the_wp_business_widgets_init' );

/* Theme Font URL */
function the_wp_business_font_url() {
	$font_url = '';
	
	/* Translators: If there are any character that are
	* not supported by PT Sans, translate this to off, do not
	* translate into your own language.
	*/
	$ptsans = _x('on','PT Sans font:on or off','the-wp-business');
	
	/* Translators: If there are any character that are
	* not supported by Roboto, translate this to off, do not
	* translate into your own language.
	*/
	$roboto = _x('on','Roboto font:on or off','the-wp-business');
	
	/* Translators: If there are any character that are
	* not supported by Roboto Condensed, translate this to off, do not
	* translate into your own language.
	*/
	$roboto_cond = _x('on','Roboto Condensed font:on or off','the-wp-business');
	
	if('off' !== $ptsans || 'off' !==  $roboto || 'off' !== $roboto_cond){
		$font_family = array();
		
		if('off' !== $ptsans){
			$font_family[] = 'PT Sans:300,400,600,700,800,900';
		}
		
		if('off' !== $roboto){
			$font_family[] = 'Roboto:400,700';
		}
		
		if('off' !== $roboto_cond){
			$font_family[] = 'Roboto Condensed:400,700';
		}
		
		$font_family[] = 'Montserrat:300,400,600,700,800,900';
		
		$query_args = array(
			'family'	=> urlencode(implode('|',$font_family)),
		);
		
		$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
	}		
	return $font_url;
}
	
/* Theme enqueue scripts */
function the_wp_business_scripts() {
	wp_enqueue_style( 'the-wp-business-font', the_wp_business_font_url(), array() );
	wp_enqueue_style( 'bootstrap', get_template_directory_uri().'/css/bootstrap.css' );
	wp_enqueue_style( 'the-wp-business-basic-style', get_stylesheet_uri() );
	wp_style_add_data( 'the-wp-business-style', 'rtl', 'replace' );
	wp_enqueue_style( 'the-wp-business-effect', get_template_directory_uri().'/css/effect.css' );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri().'/css/font-awesome.css' );
	if ( is_home() || is_front_page() ) { 
		wp_enqueue_style( 'jquery-nivo-slider', get_template_directory_uri().'/css/nivo-slider.css' );
		wp_enqueue_script( 'jquery-nivo-slider', get_template_directory_uri() . '/js/jquery.nivo.slider.js', array('jquery') );
		wp_enqueue_script( 'the-wp-business-custom-front', get_template_directory_uri() . '/js/custom-front.js', array('jquery') ,'',true);
	}
	wp_enqueue_script( 'the-wp-business-customscripts', get_template_directory_uri() . '/js/custom.js', array('jquery') );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	/** Load our IE-only stylesheet for all versions of IE.
	*   <!--[if lt IE 9]> ... <![endif]-->
	*
	*  Note: It is also possible to just check and see if the $is_IE global in WordPress is set to true before
	*  calling the wp_enqueue_style() function. If you are trying to load a stylesheet for all browsers
	*  EXCEPT for IE, then you would HAVE to check the $is_IE global since WordPress doesn't have a way to
	*  properly handle non-IE conditional comments.
	*/
	wp_enqueue_style('the-wp-business-ie', get_template_directory_uri().'/css/ie.css', array('the-wp-business-ie-style'));
	wp_style_add_data( 'the-wp-business-ie', 'conditional', 'IE' );
}
add_action( 'wp_enqueue_scripts', 'the_wp_business_scripts' );

define('THE_WP_BUSINESS_SITE_URL','http://www.themesglance.com');
/* Theme Credit link */
function the_wp_business_credit_link() {
    echo "<a href=".esc_url(THE_WP_BUSINESS_SITE_URL)." target='_blank'>".esc_html('THEMES GLANCE','the-wp-business')."</a>";
}


function the_wp_business_bg_styles_header($img_name)
{
    echo "<style type='text/css'> .bg_header{ background-image:url('".esc_url(get_template_directory_uri())."/images/".esc_html($img_name)."') }</style>";
   
}

function the_wp_business_ft_bg_styles_header()
{
    echo "style=\"background-color:".esc_html(get_theme_mod('the_wp_business_section_color5')).";background-image:url('".esc_html(get_theme_mod('the_wp_business_section_image5'))."')\"";
}

function render_class_thumb()
{
    if(has_post_thumbnail()){ ?>col-md-6"<?php } else{ ?>col-md-12"<?php }
}

/*radio button sanitization*/

 function the_wp_business_sanitize_choices( $input, $setting ) {

    global $wp_customize; 

    $control = $wp_customize->get_control( $setting->id ); 

    if ( array_key_exists( $input, $control->choices ) ) {

        return $input;

    } else {

        return $setting->default;

    }
}

/* Custom template tags for this theme. */
require get_template_directory() . '/inc/template-tags.php';
/* Customizer additions. */
require get_template_directory() . '/inc/customizer.php';

/* Implement the Custom Header feature. */
require get_template_directory() . '/inc/custom-header.php';
?>