<?php
/**
 * The WP Business Theme Customizer
 *
 * @package The WP Business
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function the_wp_business_customize_register( $wp_customize ) {	

	//add home page setting pannel
	$wp_customize->add_panel( 'the_wp_business_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'TG Settings', 'the-wp-business' ),
	    'description' => __( 'Description of what this panel does.', 'the-wp-business' ),
	) );

	//Layouts
	$wp_customize->add_section( 'the_wp_business_left_right', array(
    	'title'      => __( 'Layout Settings', 'the-wp-business' ),
		'priority'   => 30,
		'panel' => 'the_wp_business_panel_id'
	) );

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('the_wp_business_theme_options',array(
	        'default' => '',
	        'sanitize_callback' => 'the_wp_business_sanitize_choices'
	    )
    );

	$wp_customize->add_control('the_wp_business_theme_options',
	    array(
	        'type' => 'radio',
	        'label' => 'Do you want this section',
	        'section' => 'the_wp_business_left_right',
	        'choices' => array(
	        	'One Column' => __('One Column','the-wp-business'),
	            'Three Columns' => __('Three Columns','the-wp-business'),
	            'Four Columns' => __('Four Columns','the-wp-business'),
	            'Left Sidebar' => __('Left Sidebar','the-wp-business'),
	            'Right Sidebar' => __('Right Sidebar','the-wp-business'),
	          	'Grid Layout' => __('Grid Layout','the-wp-business')
	        ),
	    )
    );

	//Topbar section
	$wp_customize->add_section('the_wp_business_topbar_icon',array(
		'title'	=> __('Topbar Section','the-wp-business'),
		'description'	=> __('Add Header Content here','the-wp-business'),
		'priority'	=> null,
		'panel' => 'the_wp_business_panel_id',
	));

	$wp_customize->add_setting('the_wp_business_contact_corporate',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('the_wp_business_contact_corporate',array(
		'label'	=> __('Add Phone Number','the-wp-business'),
		'section'	=> 'the_wp_business_topbar_icon',
		'setting'	=> 'the_wp_business_contact_corporate',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('the_wp_business_email_corporate',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('the_wp_business_email_corporate',array(
		'label'	=> __('Add Email','the-wp-business'),
		'section'	=> 'the_wp_business_topbar_icon',
		'setting'	=> 'the_wp_business_email_corporate',
		'type'		=> 'text'
	));


	//Social Icons(topbar)
	$wp_customize->add_section('the_wp_business_topbar_header',array(
		'title'	=> __('Social Icon Section','the-wp-business'),
		'description'	=> __('Add Header Content here','the-wp-business'),
		'priority'	=> null,
		'panel' => 'the_wp_business_panel_id',
	));

	$wp_customize->add_setting('the_wp_business_youtube_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	
	$wp_customize->add_control('the_wp_business_youtube_url',array(
		'label'	=> __('Add Youtube link','the-wp-business'),
		'section'	=> 'the_wp_business_topbar_header',
		'setting'	=> 'the_wp_business_youtube_url',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('the_wp_business_facebook_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	
	$wp_customize->add_control('the_wp_business_facebook_url',array(
		'label'	=> __('Add Facebook link','the-wp-business'),
		'section'	=> 'the_wp_business_topbar_header',
		'setting'	=> 'the_wp_business_facebook_url',
		'type'	=> 'text'
	));

	$wp_customize->add_setting('the_wp_business_twitter_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	
	$wp_customize->add_control('the_wp_business_twitter_url',array(
		'label'	=> __('Add Twitter link','the-wp-business'),
		'section'	=> 'the_wp_business_topbar_header',
		'setting'	=> 'the_wp_business_twitter_url',
		'type'	=> 'text'
	));

	$wp_customize->add_setting('the_wp_business_rss_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	
	$wp_customize->add_control('the_wp_business_rss_url',array(
		'label'	=> __('Add RSS link','the-wp-business'),
		'section'	=> 'the_wp_business_topbar_header',
		'setting'	=> 'the_wp_business_rss_url',
		'type'	=> 'text'
	));


	//home page slider
	$wp_customize->add_section( 'the_wp_business_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'the-wp-business' ),
		'priority'   => 30,
		'panel' => 'the_wp_business_panel_id'
	) );

	for ( $count = 1; $count <= 4; $count++ ) {

		// Add color scheme setting and control.
		$wp_customize->add_setting( 'the_wp_business_slidersettings-page-' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'absint'
		) );

		$wp_customize->add_control( 'the_wp_business_slidersettings-page-' . $count, array(
			'label'    => __( 'Select Slide Image Page', 'the-wp-business' ),
			'section'  => 'the_wp_business_slidersettings',
			'type'     => 'dropdown-pages'
		) );

	}


	//we think
	$wp_customize->add_section('the_wp_business_wethink',array(
		'title'	=> __('We Think Section','the-wp-business'),
		'description'	=> __('Add We Think sections below.','the-wp-business'),
		'panel' => 'the_wp_business_panel_id',
	));

	$post_list = get_posts();
	$i = 0;
	foreach($post_list as $post){
		$posts[$post->post_title] = $post->post_title;
	}

	$wp_customize->add_setting('the_wp_business_wethink_post_setting',array(
		'sanitize_callback' => 'sanitize_text_field',
	));

	$wp_customize->add_control('the_wp_business_wethink_post_setting',array(
		'type'    => 'select',
		'choices' => $posts,
		'label' => __('Select post','the-wp-business'),
		'section' => 'the_wp_business_wethink',
	));

		$wp_customize->add_section('the_wp_business_footer_section',array(
			'title'	=> __('Footer Text','the-wp-business'),
			'description'	=> '',
			'priority'	=> null,
			'panel' => 'the_wp_business_panel_id',
		));
		
		$wp_customize->add_setting('the_wp_business_footer_copy',array(
			'default'	=> '',
			'sanitize_callback'	=> 'sanitize_text_field',
		));
		
		$wp_customize->add_control('the_wp_business_footer_copy',array(
			'label'	=> __('Copyright Text','the-wp-business'),
			'section'	=> 'the_wp_business_footer_section',
			'type'		=> 'textarea'
		));
	
}
add_action( 'customize_register', 'the_wp_business_customize_register' );	


/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class the_wp_business_customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'the_wp_business_customize_Section_Pro' );

		// Register sections.
		$manager->add_section(
			new the_wp_business_customize_Section_Pro(
				$manager,
				'example_1',
				array(
					'title'    => esc_html__( 'Upgrade to Pro', 'the-wp-business' ),
					'pro_text' => esc_html__( 'Go Pro',         'the-wp-business' ),
					'pro_url'  => 'http://www.themesglance.com/premium/wp-business-wordpress-theme/'
				)
			)
		);
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'the-wp-business-customize-controls', trailingslashit( get_template_directory_uri() ) . '/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'the-wp-business-customize-controls', trailingslashit( get_template_directory_uri() ) . '/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
the_wp_business_customize::get_instance();